/*

  Breakorino
  
  A little game for dogm128 graphics module.

  (c) 2010 Oliver Kraus (olikraus@gmail.com)
  
  This file is part of the dogm128 library.

  The dogm128 library is free software: you can redistribute it and/or modify
  it under the terms of the Lesser GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  The dogm128 library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  Lesser GNU General Public License for more details.

  You should have received a copy of the Lesser GNU General Public License
  along with dogm128.  If not, see <http://www.gnu.org/licenses/>.


  SCL (SPI Clock)   Pin 13
  SI (MOSI)         Pin 11
  CS (Chip Select)  Pin 10
  MISO (Pin 12) is not used, but can not be reused as generic I/O
  
  Note:
    1) Set correct display hardware in Dogm/utility/dogm128.h
    2) Set top/bottom view (DOG_REVERSE) in Dogm/utility/dogm128.h
    See also: http://code.google.com/p/dogm128/wiki/install 
    
  User Interface:
    Analog Potentiometer: 
      Assign pin number to variable "sensorPin". Default is analog pin 0.
    Digital Input:
      Assign left button pin to variable uiKeyLeftPin. Default is DOGS102 Shield
      Assign right button pin to variable uiKeyRightPin. Default is DOGS102 Shield
  
*/

#include <Dogm.h>

#ifdef DOGM132_HW
#error Breakorino can not be used on a DOGM132 display
#endif


int a0Pin = 1;      // address line a0 for the dogm module
int sensorPin = 0;  // analog input

// configuration values
uint8_t uiKeyLeftPin = 4;
uint8_t uiKeyRightPin = 2;
uint8_t uiMinIncrement = 2*8;
uint8_t uiMaxIncrement = 4*8;

// output values
uint8_t playerLocation = 0;

// internal values
uint8_t isKeyPad = 0;
uint8_t uiActualIncrement = 2*8;

// initialize the dogm library
Dogm dogm(a0Pin);

// setup the user interface
void uiSetup(void) {
  // configure input keys 
  pinMode(uiKeyLeftPin, INPUT);           // set pin to input
  digitalWrite(uiKeyLeftPin, HIGH);       // turn on pullup resistors
  pinMode(uiKeyRightPin, INPUT);           // set pin to input
  digitalWrite(uiKeyRightPin, HIGH);       // turn on pullup resistors
  // configure internal variables
  isKeyPad = 0;
  // assign some (more or less) useful values to the output variables
  playerLocation = 127;
}

// calculate new output values
void uiStep(void) {
 
    int sensorValue;
    // assume, that no keypad is used and derive the location from analog input
    sensorValue = analogRead(sensorPin);
    sensorValue >>= 1;
    playerLocation = sensorValue;
}


void setup() {
  uiSetup();
  bo_Setup(0);
      DDRB |= (1<<PB0);
  PORTB |= (1<<PB0);
  
   DDRB |= (1<<PB1);
  PORTB |= (1<<PB1);
  
    pinMode(4, OUTPUT);  // Activate Buttons
  digitalWrite(4, HIGH);  
}

void loop() {
  dogm.start();
  do{
    bo_Draw();
  } while( dogm.next() );
  dog_Delay(1);
  uiStep();
  bo_SetX(playerLocation);
  bo_Step();  
}


